@@ -22,6 +22,7 @@
 #ifndef FDUPES_H
 #define FDUPES_H
 
+#include "config.h"
 #include <sys/stat.h>
 #include "md5/md5.h"
 
@@ -34,6 +35,8 @@ typedef struct _file {
   ino_t inode;
   time_t mtime;
   time_t ctime;
+  long mtime_nsec;
+  long ctime_nsec;
   int hasdupes; /* true only if file is first on duplicate chain */
   struct _file *duplicates;
   struct _file *next;
